/*
    \brief Deklarationen der Funktionen für die Arbeit mit Timeboylisten.

    \author Bernd Ottmann
    \date   21.02.2003
*/
#pragma once
#ifndef DATAFOX_TIMEBOY_LISTS_H
#ifndef DOXYGEN_SHOULD_SKIP_THIS
#define DATAFOX_TIMEBOY_LISTS_H
#endif

#include "df_defines.h"

#if (DF_API_VERSION >= 0x04010400)

/*!
    \brief Bibliotheksinterne Datenpuffer für Timeboylistendaten löschen und initalisieren.

    Die in der Bibliothek bereitgestellten Datenpuffer für die zu übertragenenden Listendaten werden gelöscht und
    für eine Verwendung mittels DFCMakeTimeboyList() und DFCLoadTimeboyList() initalisiert.

    \ingroup timeboy_lists

    \export{_DFCClearTimeboyListBuffer@12, DFCClearTimeboyListBuffer}

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] groupNumber Gruppennummer der Liste. Bereich -1 bist 19. Mit der Angabe von -1 werden alle Gruppen angesprochen.
    \param[in] number Listennummer. Bereich -1 bist 19. Bei einer Angabe von -1 werden alle Datenpuffer gelöscht.

    \since 04.01.04 enthalten
*/
DF_API_EXTERN_DECORATE void DF_API_CALL DFCClearTimeboyListBuffer( int connectionId, int groupNumber, int number );

/*!
    \brief Kopieren eines aufbereiteten Datenarrays für eine Timeboyliste in den Biblioteksinternen Datenpuffer.

    Der zu übergebende Datenpuffer wird in den Bibliotheksinternen Datenpuffer kopiert und für eine spätere
    Übertragung mittels DFCLoadTimeboyList() zwischengespeichert.

    \ingroup timeboy_lists

    \export{_DFCMakeTimeboyList@32, DFCMakeTimeboyList}

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] groupNumber Gruppennummer der Liste. Bei Angabe von 0 ist die so übergebene Liste für alle Gruppen gültig.
    \param[in] number Listennummer.
    \param[in] recordCount Anzahl der Datensätze im übergebenen Datenarray.
    \param[in] size Anzahl Byte des Datenarrays.\n Brechnet sich aus (recordCount * Größe pro Datensatz).
    \param[in] buffer Datenarray mit den Daten.
    \param[in] flags Angebbare Flags zur Liste. Z.B. Bit 1 ob Liste gelöscht werden soll.
    \param[out] errorNumber Fehlernummer bei fehlerhafter Ausführung.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.01.04 enthalten
*/
DF_API_EXTERN_DECORATE int DF_API_CALL DFCMakeTimeboyList( int connectionId, int groupNumber, int number, int recordCount, 
                                                          int size, const unsigned char *buffer, int flags, int *errorNumber );

/*!
    \brief Übertragen der bibliotheksinternen Datenpuffer zum Gerät.

    Es werden die mit DFCMakeTimeboyList() importierten Listendaten in das Gerät geschrieben. Vorhandene Listendaten
    werden hierbei erst nach einer erfolgreichen Übernahme überschrieben.

    \ingroup timeboy_lists

    \export{_DFCLoadTimeboyList@24, DFCLoadTimeboyList}

    \param[in] connectionId Zu verwendende Verbindungs-Id.
    \param[in] deviceAddress Anzusprechende Geräteadresse.
    \param[in] groupNumber Gruppennummer. Eine Angabe von -1 meint alle Gruppen.
    \param[in] number Listennummer.  Bei Angabe von -1 werden alle importierten Listen zur angegebenen Gruppe übertragen.
    \param[in] unused_setTo0 Reservierter Parameter, aktuell mit 0 übergeben.
    \param[out] errorNumber Fehlernummer bei fehlerhafter Ausführung.

    \retval 0 Fehler bei Ausführung.
    \retval 1 Ausführung war erfolgreich.

    \since 04.01.04 enthalten
*/
DF_API_EXTERN_DECORATE int DF_API_CALL DFCLoadTimeboyList( int connectionId, int deviceAddress, int groupNumber, int number, 
                                                          int unused_setTo0, int *errorNumber );

#endif

#endif
