#pragma once
#ifndef FIRMWARE_OPTIONS_H
#define FIRMWARE_OPTIONS_H

#include <set>

class FirmwareOptions
{
public:
    FirmwareOptions();
    virtual ~FirmwareOptions();

public:
    void clear();

public:
    enum EnumValues
    {
        All,
        SystemFlags,
        TypeExternalReader,
        OptionIOModule,
        OptionTBAdaption,
        OptionComServer,
        OptionTPWrite,
        OptionHTTP,
        OptionLanguage,
        OptionBiokeyUpdate,
        SetupOptions,
        PayableOptions
    };
    std::set<EnumValues> selectedValues;

    void setSystemFlags( unsigned int flags );
    unsigned int getSystemFlags( unsigned int mask ) const;
    unsigned int getSystemFlags() const;

    void setTypeExternalReader( unsigned char type );
    unsigned char getTypeExternalReader();

    void setOptionIOModule( unsigned char enabled );
    unsigned char getOptionIOModule();

    void setOptionTBAdaption( unsigned char enabled );
    unsigned char getOptionTBAdaption();

    void setOptionComServer( unsigned char enabled );
    unsigned char getOptionComServer();

    void setOptionTPWrite( unsigned char enabled );
    unsigned char getOptionTPWrite();

    void setOptionHTTP( unsigned char enabled );
    unsigned char getOptionHTTP();

    void setOptionLanguage( unsigned char enabled );
    unsigned char getOptionLanguage();

    void setOptionBiokeyUpdate( unsigned char enabled );
    unsigned char getOptionBiokeyUpdate();

    void setSetupOptions( unsigned short mask, unsigned short options );
    unsigned short getSetupOptions( unsigned short mask );
    unsigned short getSetupOptions();
    unsigned short getSetupOptionsMask();

    enum EnumPayableOption
    {
        PayableOptionDataOnCard = 1,
        PayableOptionExtendedFlash = 2
    };

    void setPayableOptions( unsigned char mask, unsigned char options );
    bool isPayableOption( EnumPayableOption option );
    unsigned char getPayableOptions();
    unsigned char getPayableOptionsMask();

private:
    unsigned int _systemFlags;
    unsigned char _typeExternalReader;
    unsigned char _optionIOModule;
    unsigned char _optionTBAdaption;
    unsigned char _optionComServer;
    unsigned char _optionTPWrite;
    unsigned char _optionHTTP;
    unsigned char _optionLanguage;
    unsigned char _optionBiokeyUpdate;

    unsigned short _setupOptionsMask;
    unsigned short _setupOptions;

    unsigned char _payableOptionsMask;
    unsigned char _payableOptions;
};

#endif
